==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/jms/RT2DcsUpdateConsumer.java <==
package com.openexchange.office.rt2.core.jms;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;

import org.apache.activemq.ActiveMQConnectionFactory;
import org.apache.activemq.command.ActiveMQTextMessage;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.task.SimpleAsyncTaskExecutor;
import org.springframework.jms.listener.DefaultMessageListenerContainer;
import org.springframework.stereotype.Service;
import org.springframework.util.backoff.ExponentialBackOff;

import com.codahale.metrics.Counter;
import com.codahale.metrics.MetricRegistry;
import com.openexchange.log.LogProperties;
import com.openexchange.office.rt2.core.cache.RT2HazelcastHelperService;
import com.openexchange.office.tools.annotation.ShutdownOrder;
import com.openexchange.office.tools.common.jms.JmsMessageListener;
import com.openexchange.office.tools.common.threading.ThreadFactoryBuilder;
import com.openexchange.office.tools.jms.PooledConnectionFactoryProxy;

@Service
@ShutdownOrder(value=-5)
public class RT2DcsUpdateConsumer implements MessageListener, JmsMessageListener, DisposableBean {

	private static final Logger log = LoggerFactory.getLogger(RT2DcsUpdateConsumer.class);

	//--------------------------Services--------------------------------------	
	
    @Autowired
    private PooledConnectionFactoryProxy pooledConnectionFactoryProxy;    

    @Autowired
    private MetricRegistry metricRegistry;
    
    @Autowired
    private RT2HazelcastHelperService rt2HazelcastHelperService;
	
	//------------------------------------------------------------------------	
    private DefaultMessageListenerContainer msgListenerCont;
    
    private Counter counter;
    
    //-------------------------------------------------------------------------
	@Override
	public void onMessage(Message msg) {
        LogProperties.putProperty(LogProperties.Name.RT2_BACKEND_PART, "RT2DcsUpdateConsumer");
        LogProperties.putProperty(LogProperties.Name.RT2_BACKEND_UID, rt2HazelcastHelperService.getHazelcastLocalNodeUuid());      	        
		counter.inc();
		ActiveMQTextMessage txtMsg = (ActiveMQTextMessage) msg;
		try {
			String newBrokerUrl = txtMsg.getText();
			ActiveMQConnectionFactory connFactory = (ActiveMQConnectionFactory) pooledConnectionFactoryProxy.getPooledConnectionFactory().getConnectionFactory();
			if (!newBrokerUrl.equals(connFactory.getBrokerURL())) {
				log.info("Received new brokerURl: {}", newBrokerUrl);			
				connFactory.setBrokerURL(newBrokerUrl);
			}
		} catch (JMSException ex) {
			log.error(ex.getErrorCode(), ex);
		}
	}
	
	//-------------------------------------------------------------------------	
	@Override
	public void startReceiveMessages() {
        if (msgListenerCont == null) {
        	this.counter = metricRegistry.counter(MetricRegistry.name("RT2DcsUpdateConsumer", "count"));
        	
            msgListenerCont = new DefaultMessageListenerContainer();
            ExponentialBackOff exponentialBackOff = new ExponentialBackOff();
            exponentialBackOff.setMaxInterval(60000);
            msgListenerCont.setBackOff(exponentialBackOff);            
            msgListenerCont.setConnectionFactory(pooledConnectionFactoryProxy.getPooledConnectionFactory());
            msgListenerCont.setConcurrentConsumers(3);
            msgListenerCont.setDestination(RT2JmsDestination.brokerChangedTopic);
            msgListenerCont.setMaxConcurrentConsumers(1);
            msgListenerCont.setPubSubDomain(true);
            msgListenerCont.setAutoStartup(true);
            msgListenerCont.setupMessageListener(this);
            msgListenerCont.setTaskExecutor(new SimpleAsyncTaskExecutor(new ThreadFactoryBuilder("RT2DcsUpdateConsumer-%d").build()));
            msgListenerCont.afterPropertiesSet();            
            msgListenerCont.start();
        }
    }	
    
	//-------------------------------------------------------------------------	
    @Override
	public void destroy() throws Exception {
        if (msgListenerCont != null) {
            msgListenerCont.destroy();
            msgListenerCont = null;
        }
	}    
}

==> open-xchange-documents-backend_7.10.5.orig.tar.bz2: open-xchange-documents-backend-7.10.5/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/jms/RT2DcsUpdateConsumer.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.office.rt2.core.jms;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;

import org.apache.activemq.ActiveMQConnectionFactory;
import org.apache.activemq.command.ActiveMQTextMessage;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.slf4j.MDC;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.task.SimpleAsyncTaskExecutor;
import org.springframework.jms.listener.DefaultMessageListenerContainer;
import org.springframework.stereotype.Service;
import org.springframework.util.backoff.ExponentialBackOff;

import com.codahale.metrics.Counter;
import com.codahale.metrics.MetricRegistry;
import com.openexchange.office.tools.annotation.ShutdownOrder;
import com.openexchange.office.tools.common.jms.JmsMessageListener;
import com.openexchange.office.tools.common.threading.ThreadFactoryBuilder;
import com.openexchange.office.tools.jms.PooledConnectionFactoryProxy;
import com.openexchange.office.tools.service.cluster.ClusterService;
import com.openexchange.office.tools.service.logging.MDCEntries;

@Service
@ShutdownOrder(value=-5)
public class RT2DcsUpdateConsumer implements MessageListener, JmsMessageListener, DisposableBean {

	private static final Logger log = LoggerFactory.getLogger(RT2DcsUpdateConsumer.class);

	//--------------------------Services--------------------------------------	
	
    @Autowired
    private PooledConnectionFactoryProxy pooledConnectionFactoryProxy;    

    @Autowired
    private MetricRegistry metricRegistry;
    
    @Autowired
    private ClusterService clusterService;
    
	//------------------------------------------------------------------------	
    private DefaultMessageListenerContainer msgListenerCont;
    
    private Counter counter;
    
    //-------------------------------------------------------------------------
	@Override
	public void onMessage(Message msg) {
		MDC.put(MDCEntries.BACKEND_PART, "RT2DcsUpdateConsumer");
		MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());      	        
		counter.inc();
		ActiveMQTextMessage txtMsg = (ActiveMQTextMessage) msg;
		try {
			String newBrokerUrl = txtMsg.getText();
			ActiveMQConnectionFactory connFactory = (ActiveMQConnectionFactory) pooledConnectionFactoryProxy.getPooledConnectionFactory().getConnectionFactory();
			if (!newBrokerUrl.equals(connFactory.getBrokerURL())) {
				log.info("Received new brokerURl: {}", newBrokerUrl);			
				connFactory.setBrokerURL(newBrokerUrl);
			}
		} catch (JMSException ex) {
			log.error(ex.getErrorCode(), ex);
		} finally {
			MDC.clear();
		}
	}
	
	//-------------------------------------------------------------------------	
	@Override
	public void startReceiveMessages() {
        if (msgListenerCont == null) {
        	this.counter = metricRegistry.counter(MetricRegistry.name("RT2DcsUpdateConsumer", "count"));
        	
            msgListenerCont = new DefaultMessageListenerContainer();
            ExponentialBackOff exponentialBackOff = new ExponentialBackOff();
            exponentialBackOff.setMaxInterval(60000);
            msgListenerCont.setBackOff(exponentialBackOff);            
            msgListenerCont.setConnectionFactory(pooledConnectionFactoryProxy.getPooledConnectionFactory());
            msgListenerCont.setConcurrentConsumers(3);
            msgListenerCont.setDestination(RT2JmsDestination.brokerChangedTopic);
            msgListenerCont.setMaxConcurrentConsumers(1);
            msgListenerCont.setPubSubDomain(true);
            msgListenerCont.setAutoStartup(true);
            msgListenerCont.setupMessageListener(this);
            msgListenerCont.setTaskExecutor(new SimpleAsyncTaskExecutor(new ThreadFactoryBuilder("RT2DcsUpdateConsumer-%d").build()));
            msgListenerCont.afterPropertiesSet();            
            msgListenerCont.start();
        }
    }	
    
	//-------------------------------------------------------------------------	
    @Override
	public void destroy() throws Exception {
        if (msgListenerCont != null) {
            msgListenerCont.destroy();
            msgListenerCont = null;
        }
	}    
}
